
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#pragma once

            #include <glib-object.h>
            #if !defined(_HANDY_INSIDE) && !defined(HANDY_COMPILATION)
#error "Only <handy.h> can be included directly."
#endif

#include "hdy-version.h"


            G_BEGIN_DECLS

/* enumerations from "hdy-deck.h" */

HDY_AVAILABLE_IN_ALL
GType hdy_deck_transition_type_get_type (void);
#define HDY_TYPE_DECK_TRANSITION_TYPE (hdy_deck_transition_type_get_type())

/* enumerations from "hdy-flap.h" */

HDY_AVAILABLE_IN_ALL
GType hdy_flap_fold_policy_get_type (void);
#define HDY_TYPE_FLAP_FOLD_POLICY (hdy_flap_fold_policy_get_type())

HDY_AVAILABLE_IN_ALL
GType hdy_flap_transition_type_get_type (void);
#define HDY_TYPE_FLAP_TRANSITION_TYPE (hdy_flap_transition_type_get_type())

/* enumerations from "hdy-header-bar.h" */

HDY_AVAILABLE_IN_ALL
GType hdy_centering_policy_get_type (void);
#define HDY_TYPE_CENTERING_POLICY (hdy_centering_policy_get_type())

/* enumerations from "hdy-header-group.h" */

HDY_AVAILABLE_IN_ALL
GType hdy_header_group_child_type_get_type (void);
#define HDY_TYPE_HEADER_GROUP_CHILD_TYPE (hdy_header_group_child_type_get_type())

/* enumerations from "hdy-leaflet.h" */

HDY_AVAILABLE_IN_ALL
GType hdy_leaflet_transition_type_get_type (void);
#define HDY_TYPE_LEAFLET_TRANSITION_TYPE (hdy_leaflet_transition_type_get_type())

/* enumerations from "hdy-navigation-direction.h" */

HDY_AVAILABLE_IN_ALL
GType hdy_navigation_direction_get_type (void);
#define HDY_TYPE_NAVIGATION_DIRECTION (hdy_navigation_direction_get_type())

/* enumerations from "hdy-squeezer.h" */

HDY_AVAILABLE_IN_ALL
GType hdy_squeezer_transition_type_get_type (void);
#define HDY_TYPE_SQUEEZER_TRANSITION_TYPE (hdy_squeezer_transition_type_get_type())

/* enumerations from "hdy-style-manager.h" */

HDY_AVAILABLE_IN_ALL
GType hdy_color_scheme_get_type (void);
#define HDY_TYPE_COLOR_SCHEME (hdy_color_scheme_get_type())

/* enumerations from "hdy-view-switcher.h" */

HDY_AVAILABLE_IN_ALL
GType hdy_view_switcher_policy_get_type (void);
#define HDY_TYPE_VIEW_SWITCHER_POLICY (hdy_view_switcher_policy_get_type())

G_END_DECLS

/* Generated data ends here */

